def reverse_digits():
    return None


def gcd(x, y):
    return None


def moving_average():
    return None


def print_polynomial():
    return None


def dest_rotate_list():
    return None


def base_b():
    return None


def corner_frame():
    return None


def medal_allocation():
    return None


def num_to_word():
    return None


def substitute_once():
    return None


def triangle():
    return None


def uniform():
    return None


def is_anagram():
    return None